# Changelog

## [1.0.2](https://github.com/CoreySpohn/coronalyze/compare/v1.0.1...v1.0.2) (2026-01-27)


### Bug Fixes

* Revert name back to coronalyze ([8dc5d93](https://github.com/CoreySpohn/coronalyze/commit/8dc5d9368db3dfeb69e7b270c9f6fb959715d5fe))

## [1.0.1](https://github.com/CoreySpohn/coronalyze/compare/v1.0.0...v1.0.1) (2026-01-26)


### Bug Fixes

* Update the wheel targets to avoid data files ([cd4299d](https://github.com/CoreySpohn/coronalyze/commit/cd4299d0e12045fdb64f7418f63ee0b4bdffe269))

## 1.0.0 (2026-01-26)


### Features

* Add literally everything ([60a8394](https://github.com/CoreySpohn/coronalyze/commit/60a83946f340c26c99d503174a11eebd2f7ae434))
* Introduce the `coronalyze` library for JAX-based coronagraphic image post-processing, including aperture photometry and SNR calculations, along with project infrastructure. ([053595f](https://github.com/CoreySpohn/coronalyze/commit/053595fc5936025493872363e35ae683a4561bde))
